#!/bin/sh

# This script updates example files

test -d ~dexter/src || exit 0

for f in \
  ~dexter/src/alioth/cvsdebuild/trunk/debian/*/*/debian/*packages \
  ~dexter/src/alioth/fakechroot/trunk/debian/*packages \
  ~dexter/src/alioth/pear-package/trunk/*/debian/*packages
do
    echo $f
    cat $f > $(basename $(dirname $(dirname $f))).$(basename $f)
done

svk add *.packages

svk ci

svk smerge --verbatim -l /yada/local /yada/trunk
